@@ -1,7 +1,10 @@
 package SQL::Dialects::CSV;
 
+use strict;
+use warnings FATAL => "all";
+
 use vars qw($VERSION);
-$VERSION = '1.401';
+$VERSION = '1.406_001';
 
 use SQL::Dialects::Role;
 
