@@ -1,14 +1,14 @@
 package SQL::Statement::Placeholder;
 
 use strict;
-use warnings;
+use warnings FATAL => "all";
 
 use vars qw(@ISA);
-require Carp;
+use Carp ();
 
-require SQL::Statement::Term;
+use SQL::Statement::Term ();
 
-our $VERSION = '1.401';
+our $VERSION = '1.406_001';
 
 @ISA = qw(SQL::Statement::Term);
 
